Zaber Python Serial Library
===========================

The Zaber Serial Library is a small Python library for communicating
with Zaber devices over a serial port. It is built on top of
`PySerial`_.

The library is compatible with Python 2.7 and 3.4. It is released under
the `Apache License`_.

.. _`PySerial`: http://pyserial.sourceforge.net/index.html
.. _`Apache License`: http://apache.org/licenses/LICENSE-2.0

